@@ -614,8 +614,7 @@ sub _output_heading
 	output( "\n" );
 	output( "<hr>\n" );
 	output( "\n" );
-	output( "<h" . ( $_[1] + 2 ) . ">" );
-	output( "<a name=\"$_[3]\"></a>" );
+	output( "<h" . ( $_[1] + 2 ) . " id=\"$_[3]\">" );
 	output( "$_[2] " ) if length( $_[2] );
 	output( $_[0] );
         output( "</h" . ( $_[1] + 2 ) . ">\n" );
@@ -956,7 +955,7 @@ sub _output_httppath
 }
 sub _output_url
 {
-    my $url = URI->new( $_[0] );
+    my $url = URI->new( _to_cdata( $_[0] ) );
     $_[1] = $_[0] if $_[1] eq "";
     output( "<code><a href=\"$url\">" );
     _cdata( $_[1] );
@@ -966,7 +965,7 @@ sub _output_url
 ## ----------------------------------------------------------------------
 ## data output subroutines
 ## ----------------------------------------------------------------------
-sub _cdata
+sub _to_cdata
 {
     ( $_ ) = @_;
 
@@ -976,7 +975,11 @@ sub _cdata
     # SDATA
     s/\\\|(\[\w+\s*\])\\\|/$sdata{ $1 }/g;
 
-    output( $_ );
+    return $_;
+}
+sub _cdata
+{
+    output( _to_cdata( $_[0] ) );
 }
 sub _sdata
 {
