@@ -65,7 +65,7 @@ use vars qw( @copyrightsummaries );
 ## ----------------------------------------------------------------------
 sub _output_start_book
 {
-    output( "\\documentclass[11pt" );
+    output( "\\documentclass[10pt" );
     output( ",$locale{ 'babel' }" ) 
     	if (length( $locale{ 'babel' } ));
     output( "]{book}\n" );
@@ -86,7 +86,7 @@ sub _output_start_book
     output( "\n" );
     output( "\\usepackage{vmargin}\n" );
     output( "\\setpapersize{$pagespec}\n" );
-    output( "\\setmarginsrb{25.4mm}{25.4mm}{25.4mm}{25.4mm}{15pt}{11mm}{0pt}{11mm}\n" );
+    output( "\\setmarginsrb{10mm}{10mm}{10mm}{10mm}{12pt}{5mm}{0pt}{5mm}\n" );
     output( "\n" );
     output( "\\usepackage{fancyhdr}\n" );
     output( "\\pagestyle{fancy}\n" );
@@ -350,6 +350,12 @@ sub _output_heading
     {
 	output( "\\subparagraph" );
     }
+    # disable \\NoAutoSpaceBeforeFDP within heading for french. Bug #594846
+    if ( $locale{ 'babel' } eq 'french' )
+    {
+	$_[0] =~ s/\{\\NoAutoSpaceBeforeFDP//g ;
+	$_[0] =~ s/\\AutoSpaceBeforeFDP\}//g ;
+    }
     output( "{$_[0]}\n" );
     output( "\\label{$_[3]}\n" ) if length( $_[3] );
     if ( ! $set_arabic )
@@ -420,9 +426,9 @@ sub _output_example
     $_[0] =~ s/\n/\n $space/g;
     $_[0] =~ s/\s+$/\n/;
     output( "\n" ) if ! $DebianDoc_SGML::Format::Driver::is_compact;
-    output( "\\begin{alltt}\n" );
+    output( "\\scriptsize\\begin{alltt}\n" );
     output( $_[0] );
-    output( "\\end{alltt}\n" );
+    output( "\\end{alltt}\\normalsize\n" );
 }
 
 ## ----------------------------------------------------------------------
@@ -533,12 +539,14 @@ sub _output_var
 }
 sub _output_package
 {
+    $_[0] =~ s/--/---/g;
     output( "{\\NoAutoSpaceBeforeFDP" ) if $locale{ 'babel' } eq 'french';
     output( "\\texttt{$_[0]}" );
     output( "\\AutoSpaceBeforeFDP}" ) if $locale{ 'babel' } eq 'french';
 }
 sub _output_prgn
 {
+    $_[0] =~ s/--/---/g;
     output( "{\\NoAutoSpaceBeforeFDP" ) if $locale{ 'babel' } eq 'french';
     output( "\\texttt{$_[0]}" );
     output( "\\AutoSpaceBeforeFDP}" ) if $locale{ 'babel' } eq 'french';
@@ -569,6 +577,8 @@ sub _output_ref
 }
 sub _output_manref
 {
+    $_[0] =~ s/--/---/g;
+    $_[0] =~ s/\\\\/\\/g;
     output( "{\\NoAutoSpaceBeforeFDP" ) if $locale{ 'babel' } eq 'french';
     output( "\\texttt{" );
     _cdata( $_[0] );
