@@ -27,8 +27,7 @@ use vars qw( %map_aliases );
 		'text'    => 'Text',
 		'wiki'    => 'Wiki',
 		'textov'  => 'TextOV',
-		'xml'	=> 'XML',
-		'sgml'	=> 'SGML',
+		'dbk'	=> 'XML',
 		);
 
 ## ----------------------------------------------------------------------
